@@ -41,7 +41,7 @@ class Mesh2D(MeshBase):
     __slots__ = ('_min', '_max', '_center', '_centroid')
 
     def __init__(self, vertices, faces, colors=None):
-        """Initilize Mesh2D."""
+        """Initialize Mesh2D."""
         self._vertices = self._check_vertices_input(vertices)
         self._faces = self._check_faces_input(faces)
         self._is_color_by_face = False  # default if colors is None
@@ -107,10 +107,10 @@ class Mesh2D(MeshBase):
         Args:
             polygon: A Polygon2D.
             purge: A boolean to indicate if duplicate vertices should be shared between
-                faces. This has no bearing on the triagnulation of convex polygons
+                faces. This has no bearing on the triangulation of convex polygons
                 and only affects concave polygons with more than 4 sides.
                 Default is True to purge duplicate vertices, which can be slow
-                for convace polygons composed of a large number of triangles but
+                for concave polygons composed of a large number of triangles but
                 ultimately results in a higher-quality mesh. Default is True.
         """
         assert isinstance(polygon, Polygon2D), 'polygon must be a Polygon2D to use ' \
@@ -347,7 +347,7 @@ class Mesh2D(MeshBase):
         This is faster than the Mesh2D.remove_faces method but will likely result
         a lower-quality mesh where several vertices exist in the mesh that are not
         referenced by any face. This may be preferred if pure speed of removing
-        faces is a priorty over smallest size of the mesh in memory.
+        faces is a priority over smallest size of the mesh in memory.
 
         Args:
             pattern: A list of boolean values denoting whether a face should
@@ -400,6 +400,43 @@ class Mesh2D(MeshBase):
                 'vertices': [pt.to_array() for pt in self.vertices],
                 'faces': self.faces, 'colors': colors}
 
+    @staticmethod
+    def join_meshes(meshes):
+        """Join an array of Mesh2Ds into a single Mesh2D.
+
+        Args:
+            meshes: An array of meshes to be joined into one.
+
+        Returns:
+            A single Mesh2D object derived from the input meshes.
+        """
+        # set up empty lists of objects to be filled
+        verts = []
+        faces = []
+        colors = []
+
+        # loop through all of the meshes and get new faces
+        total_v_i = 0
+        for mesh in meshes:
+            verts.extend(mesh._vertices)
+            for fc in mesh._faces:
+                faces.append(tuple(v_i + total_v_i for v_i in fc))
+            if mesh._colors:
+                colors.extend(mesh._colors)
+
+        # create the new mesh
+        if len(colors) != 0:
+            new_mesh = Mesh2D(verts, faces, colors)
+        else:
+            new_mesh = Mesh2D(verts, faces)
+
+        # attempt to transfer the centroids and normals
+        if all(msh._face_centroids is not None for msh in meshes):
+            new_mesh._face_centroids = tuple(pt for msh in meshes for pt in msh)
+        if all(msh._face_areas is not None for msh in meshes):
+            new_mesh._face_areas = tuple(a for msh in meshes for a in msh.face_areas)
+        return new_mesh
+
     def _calculate_min_max(self):
         """Calculate maximum and minimum Point2D for this object."""
         min_pt = [self.vertices[0].x, self.vertices[0].y]
