@@ -42,7 +42,7 @@ class Mesh3D(MeshBase):
     __slots__ = ('_min', '_max', '_center', '_face_normals', '_vertex_normals')
 
     def __init__(self, vertices, faces, colors=None):
-        """Initilize Mesh3D."""
+        """Initialize Mesh3D."""
         self._vertices = self._check_vertices_input(vertices)
         self._faces = self._check_faces_input(faces)
 
@@ -231,7 +231,7 @@ class Mesh3D(MeshBase):
         This is faster than the Mesh3D.remove_faces method but will likely result
         a lower-quality mesh where several vertices exist in the mesh that are not
         referenced by any face. This may be preferred if pure speed of removing
-        faces is a priorty over smallest size of the mesh in memory.
+        faces is a priority over smallest size of the mesh in memory.
 
         Args:
             pattern: A list of boolean values denoting whether a face should
@@ -352,6 +352,45 @@ class Mesh3D(MeshBase):
             base['colors'] = [col.to_dict() for col in self.colors]
         return base
 
+    @staticmethod
+    def join_meshes(meshes):
+        """Join an array of Mesh3Ds into a single Mesh3D.
+
+        Args:
+            meshes: An array of meshes to be joined into one.
+
+        Returns:
+            A single Mesh3D object derived from the input meshes.
+        """
+        # set up empty lists of objects to be filled
+        verts = []
+        faces = []
+        colors = []
+
+        # loop through all of the meshes and get new faces
+        total_v_i = 0
+        for mesh in meshes:
+            verts.extend(mesh._vertices)
+            for fc in mesh._faces:
+                faces.append(tuple(v_i + total_v_i for v_i in fc))
+            if mesh._colors:
+                colors.extend(mesh._colors)
+
+        # create the new mesh
+        if len(colors) != 0:
+            new_mesh = Mesh3D(verts, faces, colors)
+        else:
+            new_mesh = Mesh3D(verts, faces)
+
+        # attempt to transfer the centroids and normals
+        if all(msh._face_centroids is not None for msh in meshes):
+            new_mesh._face_centroids = tuple(pt for msh in meshes for pt in msh)
+        if all(msh._face_normals is not None for msh in meshes):
+            new_mesh._face_normals = tuple(v for msh in meshes for v in msh.face_normals)
+        if all(msh._face_areas is not None for msh in meshes):
+            new_mesh._face_areas = tuple(a for msh in meshes for a in msh.face_areas)
+        return new_mesh
+
     def _calculate_min_max(self):
         """Calculate maximum and minimum Point3D for this object."""
         min_pt = [self.vertices[0].x, self.vertices[0].y, self.vertices[0].z]
