@@ -29,13 +29,13 @@ class Polyface3D(Base2DIn3D):
         edge_information: Optional edge information, which will speed up the
             creation of the Polyface object if it is available but should be left
             as None if it is unknown. If None, edge_information will be computed
-            from the vertices and face_indices inuputs. Edge information
+            from the vertices and face_indices inputs. Edge information
             should be formatted as a dictionary with two keys as follows:
 
             *   'edge_indices':
                 An array objects that each contain two integers.
                 These integers correspond to indices within the vertices list and
-                each tuple represents a line sengment for an edge of the polyface.
+                each tuple represents a line segment for an edge of the polyface.
             *   'edge_types':
                 An array of integers for each edge that parallels the edge_indices
                 list. An integer of 0 denotes a naked edge, an integer of 1
@@ -64,7 +64,7 @@ class Polyface3D(Base2DIn3D):
                  '_area', '_volume', '_is_solid')
 
     def __init__(self, vertices, face_indices, edge_information=None):
-        """Initilize Polyface3D."""
+        """Initialize Polyface3D."""
         # assign input properties
         Base2DIn3D.__init__(self, vertices)
         self._face_indices = tuple(tuple(tuple(loop) for loop in face)
@@ -134,8 +134,8 @@ class Polyface3D(Base2DIn3D):
                    data['face_indices'], edge_information)
 
     @classmethod
-    def from_faces(cls, faces, tolerance=0):
-        """Initilize Polyface3D from a list of Face3D objects.
+    def from_faces(cls, faces, tolerance):
+        """Initialize Polyface3D from a list of Face3D objects.
 
         Note that the Polyface3D.faces property of the resulting polyface will
         have an order of faces that matches the order input to this classmethod.
@@ -143,7 +143,7 @@ class Polyface3D(Base2DIn3D):
         Args:
             faces: A list of Face3D objects representing the boundary of this Polyface.
             tolerance: The maximum difference between x, y, and z values at which
-                the vertex of two adjacent faces is considered the same. Default: 0.
+                the vertex of two adjacent faces is considered the same.
         """
         # extract unique vertices from the faces
         vertices = []  # collection of vertices as point objects
@@ -170,7 +170,7 @@ class Polyface3D(Base2DIn3D):
 
     @classmethod
     def from_box(cls, width, depth, height, base_plane=None):
-        """Initilize Polyface3D from parameters describing a box.
+        """Initialize Polyface3D from parameters describing a box.
 
         Initializing a polyface this way has the added benefit of having its
         faces property quickly calculated.
@@ -213,7 +213,7 @@ class Polyface3D(Base2DIn3D):
 
     @classmethod
     def from_offset_face(cls, face, offset):
-        """Initilize a solid Polyface3D from a Face3D offset along its normal.
+        """Initialize a solid Polyface3D from a Face3D offset along its normal.
 
         The resulting polyface will always be offset in the direction of
         the face normal.
@@ -303,7 +303,7 @@ class Polyface3D(Base2DIn3D):
                     holes = tuple(tuple(self.vertices[i] for i in f) for f in face[1:])
                     faces.append(Face3D(boundary=boundary, holes=holes))
             if self._is_solid:
-                self._faces = Polyface3D.get_outward_faces(faces)
+                self._faces = Polyface3D.get_outward_faces(faces, 0.01)
             else:
                 self._faces = tuple(faces)
         return self._faces
@@ -314,7 +314,7 @@ class Polyface3D(Base2DIn3D):
         if self._edges is None:
             self._edges = tuple(LineSegment3D.from_end_points(
                 self.vertices[seg[0]], self.vertices[seg[1]])
-                                for seg in self._edge_indices)
+                for seg in self._edge_indices)
         return self._edges
 
     @property
@@ -711,8 +711,8 @@ class Polyface3D(Base2DIn3D):
         return True  # overlap exists
 
     @staticmethod
-    def get_outward_faces(faces, tolerance=0):
-        """Get faces that are all pointing outward from a list of faces together forming a solid.
+    def get_outward_faces(faces, tolerance):
+        """Turn a list of faces forming a solid into one where they all point outward.
 
         Note that, if the input faces do not form a closed solid, there may be some
         output faces that are not pointing outward.  However, if the gaps in the
@@ -805,7 +805,7 @@ class Polyface3D(Base2DIn3D):
         _new_poly = Polyface3D(self.vertices, self.face_indices, self.edge_information)
         _new_poly._faces = self._faces
         return _new_poly
-    
+
     def __key(self):
         """A tuple based on the object properties, useful for hashing."""
         return tuple(hash(pt) for pt in self._vertices) + \
